import { FetchOptions } from './type';
/**
 * A React hook that fetches data from a specified URL with retry logic implemented.
 * This hook attempts to make an HTTP GET request to retrieve data and will retry if the fetch fails
 * until the maximum number of retries is reached.
 * @param url The URL from which to fetch data.
 * @param options Optional parameters to control the fetch behavior:
 *  - `retries`: The number of times to retry the fetch request after a failure. Defaults to 3.
 *  - `retryDelay`: The time in milliseconds to wait between retries. Defaults to 1000 ms.
 *
 * @returns A tuple:
 *  - `data`: The fetched data of type T or null if the fetch is unsuccessful or not yet completed.
 *  - `loading`: A boolean indicating whether the fetch request is ongoing.
 *  - `error`: An error object if an error occurred during the fetch operation; otherwise, null.
 *
 */
export declare function useFetchWithRetry<T>(url: string, options?: Partial<FetchOptions>): [T | null, boolean, unknown];
